#!/usr/bin/env python

from distutils.core import setup

setup(name='ptyprocess',
      version='0.5.1',
      description='Run a subprocess in a pseudo terminal',
      author='Thomas Kluyver',
      author_email='thomas@kluyver.me.uk',
      url='https://github.com/pexpect/ptyprocess',
      packages=['ptyprocess']
     )
